@@ -666,31 +666,31 @@ class Worker(Process):
             job.perform()
 
         except MaxConcurrencyInterrupt as e:
-            self.log.error("Max concurrency reached: %s" % str(e))
+            self.log.exception("Max concurrency reached: %s" % str(e))
             job._save_status("maxconcurrency", exception=True)
 
         except RetryInterrupt as e:
-            self.log.error("Caught retry: %s" % str(e))
+            self.log.exception("Caught retry: %s" % str(job.data['path']))
             job.save_retry(sys.exc_info()[1])
 
         except MaxRetriesInterrupt as e:
-            self.log.error("Max retries reached: %s" % str(e))
+            self.log.exception("Max retries reached: %s" % str(e))
             job._save_status("maxretries", exception=True)
 
         except AbortInterrupt as e:
-            self.log.error("Caught abort: %s" % str(e))
+            self.log.exception("Caught abort: %s" % str(e))
             job.save_abort()
 
         except TimeoutInterrupt:
-            self.log.error("Job timeouted after %s seconds" % job.timeout)
+            self.log.exception("Job timeouted after %s seconds" % job.timeout)
             job._save_status("timeout", exception=True)
 
         except JobInterrupt as e:
-            self.log.error("Job interrupted: %s" % str(e))
+            self.log.exception("Job interrupted: %s" % str(e))
             job._save_status("interrupt", exception=True)
 
         except Exception as e:
-            self.log.exception("Job %s failed: %s" % str(job.data['path']) % str(e))
+            self.log.exception("Job %s failed: %s" % (str(job.data['path']), str(e)))
             job._save_status("failed", exception=True)
 
         finally:
